@@ -22,14 +22,20 @@ def wrap_method(func):
         return func(*args, **kwargs)
     return _wrapped
 
+def make_settings(ignore=None):
+    settings = {}
+    ignore = ignore or ()
+    for s in KNOWN_SETTINGS:
+        setting = s()
+        if setting.name in ignore:
+            continue
+        settings[setting.name] = setting.copy()
+    return settings
+
 class Config(object):
         
     def __init__(self, usage=None):
-        self.settings = {}
-        for s in KNOWN_SETTINGS:
-            setting = s()
-            self.settings[setting.name] = setting.copy()
-        
+        self.settings = make_settings()
         self.usage = usage
         
     def __getattr__(self, name):
@@ -102,10 +108,10 @@ class Config(object):
     @property
     def proc_name(self):
         pn = self.settings['proc_name'].get()
-        if pn:
+        if pn is not None:
             return pn
         else:
-            return self.settings['default_proc_name']
+            return self.settings['default_proc_name'].get()
             
 class SettingMeta(type):
     def __new__(cls, name, bases, attrs):
@@ -315,6 +321,25 @@ class WorkerConnections(Setting):
         This setting only affects the Eventlet and Gevent worker types.
         """
 
+class MaxRequests(Setting):
+    name = "max_requests"
+    section = "Worker Processes"
+    cli = ["--max-requests"]
+    meta = "INT"
+    validator = validate_pos_int
+    type = "int"
+    default = 0
+    desc = """\
+        The maximum number of requests a worker will process before restarting.
+        
+        Any value greater than zero will limit the number of requests a work
+        will process before automatically restarting. This is a simple method
+        to help limit the damage of memory leaks.
+        
+        If this is set to zero (the default) then the automatic worker
+        restarts are disabled.
+        """
+
 class Timeout(Setting):
     name = "timeout"
     section = "Worker Processes"
@@ -518,7 +543,7 @@ class Procname(Setting):
     cli = ["-n", "--name"]
     meta = "STRING"
     validator = validate_string
-    default = "gunicorn"
+    default = None
     desc = """\
         A base to use with setproctitle for process naming.
         
@@ -632,3 +657,19 @@ class PostRequest(Setting):
         The callable needs to accept two instance variables for the Worker and
         the Request.
         """
+
+class WorkerExit(Setting):
+    name = "worker_exit"
+    section = "Server Hooks"
+    validator = validate_callable(2)
+    type = "callable"
+    def def_worker_exit(server, worker):
+        pass
+    def_worker_exit = staticmethod(def_worker_exit)
+    default = def_worker_exit
+    desc = """\
+        Called just after a worker has been exited.
+
+        The callable needs to accept two instance variables for the Arbiter and
+        the just-exited Worker.
+        """
