@@ -6,10 +6,14 @@
 from __future__ import with_statement
 
 import os
+import sys
+
+# workaround on osx, disable kqueue
+if sys.platform == "darwin":
+    os.environ['EVENT_NOKQUEUE'] = "1"
+
 
 import gevent
-from gevent import monkey
-monkey.noisy = False
 from gevent.pool import Pool
 from gevent.server import StreamServer
 from gevent import pywsgi, wsgi
@@ -37,9 +41,8 @@ class GGeventServer(StreamServer):
         self.handle_func = handle
         self.worker = worker
 
-    def stop(self):
-        super(GGeventServer, self).stop()
-        self.worker.alive = False
+    def stop(self, timeout=None):
+        super(GGeventServer, self).stop(timeout=timeout)
 
     def handle(self, sock, addr):
         self.handle_func(sock, addr)
@@ -52,8 +55,10 @@ class GeventWorker(AsyncWorker):
     @classmethod  
     def setup(cls):
         from gevent import monkey
+        monkey.noisy = False
         monkey.patch_all()
         
+        
     def timeout_ctx(self):
         return gevent.Timeout(self.cfg.keepalive, False)
 
@@ -72,12 +77,22 @@ class GeventWorker(AsyncWorker):
                 if self.ppid != os.getppid():
                     self.log.info("Parent changed, shutting down: %s" % self)
                     break
-                gevent.sleep(self.timeout)
+                gevent.sleep(0.1) 
+        except KeyboardInterrupt:
+            pass
+
+        try:
+            # Try to stop connections until timeout
+            self.notify()
+            server.stop(timeout=self.timeout)
         except:
             pass
 
-        with gevent.Timeout(self.timeout, False):
-            gevent.spawn(server.stop).join()
+    def handle_request(self, *args):
+        try:
+            super(GeventWorker, self).handle_request(*args)
+        except gevent.GreenletExit:
+            pass
 
     def init_process(self):
         #gevent doesn't reinitialize dns for us after forking
@@ -106,6 +121,7 @@ class GeventBaseWorker(Worker):
     def setup(cls):
         from gevent import monkey
         monkey.patch_all()
+
         
     def run(self):
         self.socket.setblocking(1)
@@ -120,14 +136,19 @@ class GeventBaseWorker(Worker):
             
                 if self.ppid != os.getppid():
                     self.log.info("Parent changed, shutting down: %s" % self)
-                    server.stop()
                     break
-                gevent.sleep(0.1) 
+                gevent.sleep(0.1)
+
         except KeyboardInterrupt:
             pass
-      
-        with gevent.Timeout(self.timeout, False):
-            gevent.spawn(server.stop).join()
+
+        # try to stop the connections
+        try:
+            self.notify()
+            server.stop(timeout=self.timeout)
+        except:
+            pass
+        
 
 class WSGIHandler(wsgi.WSGIHandler):
     def log_request(self, *args):
